import { Component, OnInit, ViewEncapsulation } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { MatDialogRef } from '@angular/material/dialog';
import {
  animate,
  state,
  style,
  transition,
  trigger,
} from '@angular/animations';

@Component({
  selector: 'notice-compose',
  templateUrl: './notice-compose.component.html',

  animations: [
    trigger('detailExpand', [
      state('collapsed', style({ height: '0px', minHeight: '0' })),
      state('expanded', style({ height: '*', minHeight: '*' })),
    ]),
  ],
  encapsulation: ViewEncapsulation.None,
})
export class NoticeComposeComponent implements OnInit {
  composeForm!: FormGroup;
  copyFields: { cc: boolean; bcc: boolean } = {
    cc: false,
    bcc: false,
  };
  quillModules: any = {
    toolbar: [
      ['bold', 'italic', 'underline'],
      [{ align: [] }, { list: 'ordered' }, { list: 'bullet' }],
      ['clean'],
    ],
  };
  dataSource = ELEMENT_DATA;
  columnsToDisplay = ['idx', 'content', 'applicationDate'];
  expandedElement: PeriodicElement | null | undefined;

  /**
   * Constructor
   */
  constructor(
    public matDialogRef: MatDialogRef<NoticeComposeComponent>,
    private _formBuilder: FormBuilder
  ) {}

  // -----------------------------------------------------------------------------------------------------
  // @ Lifecycle hooks
  // -----------------------------------------------------------------------------------------------------

  /**
   * On init
   */
  ngOnInit(): void {}

  // -----------------------------------------------------------------------------------------------------
  // @ Public methods
  // -----------------------------------------------------------------------------------------------------

  /**
   * Show the copy field with the given field name
   *
   * @param name
   */
  showCopyField(name: string): void {
    // Return if the name is not one of the available names
    if (name !== 'cc' && name !== 'bcc') {
      return;
    }

    // Show the field
    this.copyFields[name] = true;
  }

  /**
   * Save and close
   */
  saveAndClose(): void {
    // Save the message as a draft
    this.saveAsDraft();

    // Close the dialog
    this.matDialogRef.close();
  }

  /**
   * Discard the message
   */
  discard(): void {}

  /**
   * Save the message as a draft
   */
  saveAsDraft(): void {}

  /**
   * Send the message
   */
  send(): void {}
}

export interface PeriodicElement {
  idx: number;
  content: string;
  applicationDate: string;
  description: string;
}

const ELEMENT_DATA: PeriodicElement[] = [
  {
    idx: 1,
    content: '계좌등록안내',
    applicationDate: '2022-08-23',
    description: `안녕하세요. 운영진입니다.`,
  },
  {
    idx: 2,
    content: '오토프로그램 이용 안내',
    applicationDate: '2022-08-23',
    description: `하단이미지를 참고해주시기바랍니다`,
  },
  {
    idx: 3,
    content: '입출금 규정 안내',
    applicationDate: '2022-08-23',
    description: `입금해라입금. 출금해라출금 이로이로ㅓㅁ;ㅇ롱러;올;ㅣㅁㄴ더ㅗ래;ㄷ로ㅑ`,
  },
];
